@@ -1,9 +1,16 @@
-/* bmcx11.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -16,9 +23,9 @@ static integer c__2 = 2;
 /* ----------------------------------------------------------------------- */
 /*     PROGRAM FOR BITMAP FILE CONVERSION FOR X               (94/05/07) */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-/* Main program */ MAIN__(void)
+/* Main program */ int MAIN__(void)
 {
     /* Format strings */
     static char fmt_100[] = "(i4,i4,i3,i3,tr1,a)";
@@ -43,11 +50,12 @@ static integer c__2 = 2;
     integer f_clos(cllist *);
 
     /* Local variables */
+    static integer i__, j, k, n, ih1, ih2, idx;
 #define cpat (equiv_0)
     static char cmsg[80];
     static integer nbit, npat, nhex, nbyt;
     static char cfmt1[8];
-    static integer ipat1, ipat2, i__, j, k, n;
+    static integer ipat1, ipat2;
     static char cline[256], cdsni[64];
     static integer iline;
     static char cdsno[64];
@@ -55,7 +63,6 @@ static integer c__2 = 2;
 #define cpatx (equiv_0)
     extern /* Subroutine */ int crvrs_(char *, ftnlen), hexdcc_(char *, char *
 	    , ftnlen, ftnlen);
-    static integer ih1, ih2, idx;
 
     /* Fortran I/O blocks */
     static cilist io___3 = { 0, 5, 0, 0, 0 };
