@@ -1,9 +1,16 @@
-/* dclpara.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -11,17 +18,17 @@ static integer c__9 = 9;
 static integer c__1 = 1;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-/* Main program */ MAIN__(void)
+/* Main program */ int MAIN__(void)
 {
     /* Builtin functions */
     integer s_wsle(cilist *), do_lio(integer *, integer *, char *, ftnlen), 
 	    e_wsle(void), s_rsle(cilist *), e_rsle(void);
 
     /* Local variables */
-    static char cgrp[3];
     static integer ii, io, np;
+    static char cgrp[3];
     extern /* Subroutine */ int glcqcp_();
     extern /* Subroutine */ int gliget_(char *, integer *, ftnlen);
     extern logical lchreq_(char *, char *, ftnlen, ftnlen);
@@ -103,10 +110,10 @@ static integer c__1 = 1;
 #define lp ((logical *)equiv_0)
     static integer iu;
 #define rp (equiv_0)
-    extern /* Subroutine */ int gliget_(char *, integer *, ftnlen), cupper_(
-	    char *, ftnlen);
     static char cp1[1];
     static integer ncp;
+    extern /* Subroutine */ int gliget_(char *, integer *, ftnlen), cupper_(
+	    char *, ftnlen);
 
     /* Fortran I/O blocks */
     static cilist io___15 = { 0, 0, 0, "(A8,A3,I10)", 0 };
@@ -167,15 +174,16 @@ static integer c__1 = 1;
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    extern integer lenc_(char *, ftnlen);
     static integer n;
-    static char cpara[80], cp[8];
+    static char cp[8];
 #define ip ((integer *)equiv_0)
 #define lp ((logical *)equiv_0)
     static integer iu;
 #define rp (equiv_0)
-    extern /* Subroutine */ int gliget_(char *, integer *, ftnlen);
     static integer ncp;
+    extern integer lenc_(char *, ftnlen);
+    static char cpara[80];
+    extern /* Subroutine */ int gliget_(char *, integer *, ftnlen);
 
     /* Fortran I/O blocks */
     static cilist io___26 = { 0, 0, 0, "(A8,A3,A)", 0 };
