@@ -1,10 +1,16 @@
-/* Copyright (C) by GFD-Dennou Club, 1999-2000.  All rights reserved. */
-/* szslti.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Common Block Declarations */
 
@@ -30,12 +36,14 @@ struct {
 /* ----------------------------------------------------------------------- */
 /*     COMMON SETTING FOR LINE SEGMENT */
 /* ----------------------------------------------------------------------- */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/* ----------------------------------------------------------------------- */
 /* Subroutine */ int szslti_(integer *itype, integer *index)
 {
+    static real rdx, rdy;
     extern /* Subroutine */ int stfrad_(real *, real *, real *, real *), 
 	    sglget_(char *, logical *, ftnlen), sgrget_(char *, real *, 
 	    ftnlen), szsidx_(integer *), szstyp_(integer *);
-    static real rdx, rdy;
 
     sglget_("LLNINT", &szbls1_1.llnint, (ftnlen)6);
     sglget_("LGCINT", &szbls1_1.lgcint, (ftnlen)6);
