@@ -1,9 +1,16 @@
-/* ucxayr.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -16,7 +23,7 @@ static integer c__4 = 4;
 /* ----------------------------------------------------------------------- */
 /*     UCXAYR : PLOT YEAR AXIS */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int ucxayr_(char *cside, integer *jd0, integer *nd, ftnlen 
 	cside_len)
@@ -34,35 +41,34 @@ static integer c__4 = 4;
     /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);
 
     /* Local variables */
-    static integer itdi, i__;
+    static integer i__;
+    static char ch[4*50];
+    static integer nn;
+    static real ux[50];
+    static integer id0, mo0, iy0;
+    static real vx1, vx2, vy1, vy2;
+    static integer idi, moi, iyi, iyl, itdi, nchx;
     extern /* Subroutine */ int cladj_(char *, ftnlen);
     static logical label;
     extern /* Subroutine */ int date13_(integer *, integer *, integer *, 
 	    integer *), date32_(integer *, integer *, integer *, integer *);
     static integer icent, irota, irotc;
     static logical lbtwn;
+    static real rsize;
     extern /* Subroutine */ int datef3_(integer *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *);
     static real rtick2;
-    static char ch[4*50];
-    static integer nn;
-    static real ux[50];
     extern integer ndyear_(integer *);
     extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
 	    ftnlen, ftnlen);
-    static integer id0;
     extern logical luxchk_(char *, ftnlen);
     extern /* Subroutine */ int uxplbl_(char *, integer *, real *, char *, 
 	    integer *, integer *, ftnlen, ftnlen), uziget_(char *, integer *, 
-	    ftnlen), uzlget_(char *, logical *, ftnlen);
-    static integer mo0;
-    extern /* Subroutine */ int uzrget_(char *, real *, ftnlen);
-    static integer iy0;
-    extern /* Subroutine */ int uziset_(char *, integer *, ftnlen), uzlset_(
-	    char *, logical *, ftnlen), uxpaxs_(char *, integer *, ftnlen), 
-	    uxptmk_(char *, integer *, real *, integer *, ftnlen), uzrset_(
-	    char *, real *, ftnlen);
-    static integer idi, moi, iyi, iyl;
+	    ftnlen), uzlget_(char *, logical *, ftnlen), uzrget_(char *, real 
+	    *, ftnlen), uziset_(char *, integer *, ftnlen), sgqvpt_(real *, 
+	    real *, real *, real *), uzlset_(char *, logical *, ftnlen), 
+	    uxpaxs_(char *, integer *, ftnlen), uxptmk_(char *, integer *, 
+	    real *, integer *, ftnlen), uzrset_(char *, real *, ftnlen);
 
     if (! luxchk_(cside, (ftnlen)1)) {
 	msgdmp_("E", "UCXAYR", "SIDE PARAMETER IS INVALID.", (ftnlen)1, (
@@ -87,6 +93,10 @@ static integer c__4 = 4;
 	iyl = ndyear_(&iyi);
 	if (itdi == iyl || i__ == *nd) {
 	    ++nn;
+	    if (nn > 50) {
+		msgdmp_("E", "UCXAYR", "WORKING AREA IS NOT ENOUGH.", (ftnlen)
+			1, (ftnlen)6, (ftnlen)27);
+	    }
 	    ux[nn - 1] = (real) i__;
 	    ici__1.icierr = 0;
 	    ici__1.icirnum = 1;
@@ -100,10 +110,9 @@ static integer c__4 = 4;
 	}
 /* L10: */
     }
-    if (nn > 50) {
-	msgdmp_("E", "UCXAYR", "WORKING AREA IS NOT ENOUGH.", (ftnlen)1, (
-		ftnlen)6, (ftnlen)27);
-    }
+    sgqvpt_(&vx1, &vx2, &vy1, &vy2);
+    uzrget_("RSIZEL2", &rsize, (ftnlen)7);
+    nchx = (vx2 - vx1) / rsize;
 /* Writing concatenation */
     i__2[0] = 6, a__1[0] = "ICENTX";
     i__2[1] = 1, a__1[1] = cside;
@@ -125,11 +134,19 @@ static integer c__4 = 4;
     i__2[1] = 1, a__1[1] = cside;
     s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
     uziset_(ch__1, &c__0, (ftnlen)7);
+    if (nn << 2 <= nchx) {
 /* Writing concatenation */
-    i__2[0] = 6, a__1[0] = "IROTLX";
-    i__2[1] = 1, a__1[1] = cside;
-    s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
-    uziset_(ch__1, &irotc, (ftnlen)7);
+	i__2[0] = 6, a__1[0] = "IROTLX";
+	i__2[1] = 1, a__1[1] = cside;
+	s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
+	uziset_(ch__1, &irotc, (ftnlen)7);
+    } else {
+/* Writing concatenation */
+	i__2[0] = 6, a__1[0] = "IROTLX";
+	i__2[1] = 1, a__1[1] = cside;
+	s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
+	uziset_(ch__1, &c__1, (ftnlen)7);
+    }
     uzlset_("LBTWN", &c_true, (ftnlen)5);
     uzrget_("RSIZET2", &rtick2, (ftnlen)7);
     r__1 = rtick2 * 1.5f;
