@@ -1,9 +1,16 @@
-/* udbset.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Common Block Declarations */
 
@@ -16,7 +23,7 @@ struct {
 /* ----------------------------------------------------------------------- */
 /*     UDBSET */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int udbset_(integer *i__, integer *j, integer *k, integer *l,
 	 integer *ibr)
@@ -29,12 +36,11 @@ struct {
     integer ibr_dim1, ibr_offset;
 
     /* Local variables */
-    static integer mask[32];
+    static integer n1, n2, ii, jj, nn, mask[32];
     static char cbpat[32];
-    extern /* Subroutine */ int crvrs_(char *, ftnlen);
-    static integer n1, n2, ii, jj, nn;
-    extern /* Subroutine */ int bitpci_(char *, integer *, ftnlen), msgdmp_(
-	    char *, char *, char *, ftnlen, ftnlen, ftnlen);
+    extern /* Subroutine */ int crvrs_(char *, ftnlen), bitpci_(char *, 
+	    integer *, ftnlen), msgdmp_(char *, char *, char *, ftnlen, 
+	    ftnlen, ftnlen);
 
     /* Parameter adjustments */
     ibr_dim1 = udblk1_1.nbr;
