@@ -1,14 +1,22 @@
-/* Copyright (C) by GFD-Dennou Club, 1999-2000.  All rights reserved. */
-/* leny.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* ----------------------------------------------------------------------- */
 /*     LENY */
 /* ----------------------------------------------------------------------- */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/* ----------------------------------------------------------------------- */
 integer leny_(char *c__, ftnlen c_len)
 {
     /* System generated locals */
@@ -18,10 +26,9 @@ integer leny_(char *c__, ftnlen c_len)
     integer i_len(char *, ftnlen);
 
     /* Local variables */
-    static integer n;
-    static logical lchar;
-    static integer lc;
+    static integer n, lc;
     static char cn[1], cs[1];
+    static logical lchar;
 
     *(unsigned char *)cn = '\0';
     *(unsigned char *)cs = ' ';
