@@ -1,9 +1,16 @@
-/* rpnopt.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -13,7 +20,7 @@ static integer c__2 = 2;
 /* ----------------------------------------------------------------------- */
 /*     GET EXTERNAL PARAMETER FROM COMMAND LINE */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int rpnopt_0_(int n__, char *cpfix, char *cp, integer *ipara,
 	 logical *lpara, real *rpara, char *cpara, ftnlen cpfix_len, ftnlen 
@@ -21,8 +28,9 @@ static integer c__2 = 2;
 {
     /* Initialized data */
 
-    static char copt[1] = "-";
-    static char cdiv[1] = "=";
+    static char csepx[1] = "_";
+    static char coptx[1] = "-";
+    static char cdivx[1] = "=";
 
     /* System generated locals */
     address a__1[4], a__2[2];
@@ -34,19 +42,17 @@ static integer c__2 = 2;
     /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
 
     /* Local variables */
-    static char carg[80];
+    static integer n, np, max__;
+    static char cpx[80], carg[80];
     extern integer lenc_(char *, ftnlen);
-    static char csep[1];
-    static integer n, np;
+    static char cdiv[1], csep[1], copt[1];
     extern logical lchreq_(char *, char *, ftnlen, ftnlen);
     extern integer ifromc_(char *, ftnlen);
     extern logical lfromc_(char *, ftnlen);
     extern /* Subroutine */ int osgarg_(integer *, char *, ftnlen);
-    extern doublereal rfromc_(char *, ftnlen);
+    extern real rfromc_(char *, ftnlen);
     extern /* Subroutine */ int osgenv_(char *, char *, ftnlen, ftnlen), 
 	    osqarn_(integer *);
-    static integer max__;
-    static char cpx[80];
 
     switch(n__) {
 	case 1: goto L_rtiopt;
@@ -61,15 +67,15 @@ static integer c__2 = 2;
 
     osgenv_("DCLENVCHAR", csep, (ftnlen)10, (ftnlen)1);
     if (*(unsigned char *)csep == ' ') {
-	*(unsigned char *)csep = ':';
+	*(unsigned char *)csep = *(unsigned char *)&csepx[0];
     }
     osgenv_("DCLOPTCHAR", copt, (ftnlen)10, (ftnlen)1);
-    if (*(unsigned char *)&copt[0] == ' ') {
-	*(unsigned char *)&copt[0] = '-';
+    if (*(unsigned char *)copt == ' ') {
+	*(unsigned char *)copt = *(unsigned char *)&coptx[0];
     }
     osgenv_("DCLSETCHAR", cdiv, (ftnlen)10, (ftnlen)1);
-    if (*(unsigned char *)&cdiv[0] == ' ') {
-	*(unsigned char *)&cdiv[0] = '=';
+    if (*(unsigned char *)cdiv == ' ') {
+	*(unsigned char *)cdiv = *(unsigned char *)&cdivx[0];
     }
     return 0;
 /* ----------------------------------------------------------------------- */
