@@ -1,55 +1,60 @@
-/* Copyright (C) by GFD-Dennou Club, 1999-2000.  All rights reserved. */
-/* shtlib.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* ********************************************************************** */
 /*     SPHERICAL HARMONICS TRANSFORMATION LIBRARY */
 /* ********************************************************************** */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/* ----------------------------------------------------------------------- */
 /* Subroutine */ int shtlib_0_(int n__, integer *mm, integer *jm, integer *im,
 	 real *q, integer *ind, real *a, real *b, integer *n, integer *m, 
 	integer *lr, integer *li, real *fun, integer *isw, real *wm, real *sm,
 	 real *s, real *w, integer *m1, integer *m2, real *wz, real *wr, real 
 	*wi, integer *j, real *wj, real *g, real *gj)
 {
-    static integer ipmj, npmj, iwfft, nwfft;
+    static integer ih, nh, ir, nr, iy, nx, ny, nz, ix, iz, isd, ixc, nsd, iyc,
+	     ipm, nyc, nxc, npm, ipx, ipy, ixs, iys, npx, npy, ixw, nxs, nys, 
+	    iyw, iwy, nxw, nyw, nwy, nwx, iwx, ipmj, npmj, iwfft, nwfft;
     extern /* Subroutine */ int shfw2g_(integer *, integer *, integer *, real 
 	    *, real *, real *, real *), shfg2w_(integer *, integer *, integer 
 	    *, real *, real *, real *, real *), shnm2l_(integer *, integer *, 
-	    integer *, integer *, integer *);
-    static integer ih;
-    extern /* Subroutine */ int shms2w_(integer *, integer *, integer *, real 
-	    *, real *, real *, real *, real *, real *, real *, real *), 
-	    shmw2s_(integer *, integer *, integer *, real *, real *, real *, 
-	    real *, real *, real *, real *, real *, real *, real *, real *);
-    static integer nh, ir, nr, iy, nx, ny, nz, ix, iz;
-    extern /* Subroutine */ int shfwga_(integer *, integer *, integer *, 
-	    integer *, integer *, real *, real *, real *, real *), sholap_(
-	    integer *, integer *, real *, real *), shfwgj_(integer *, integer 
-	    *, integer *, integer *, real *, real *, real *, real *), shfwgm_(
-	    integer *, integer *, integer *, real *, real *, real *, real *, 
-	    real *), shinit_(integer *, integer *, integer *, real *, real *, 
+	    integer *, integer *, integer *), shms2w_(integer *, integer *, 
+	    integer *, real *, real *, real *, real *, real *, real *, real *,
+	     real *), shmw2s_(integer *, integer *, integer *, real *, real *,
+	     real *, real *, real *, real *, real *, real *, real *, real *, 
+	    real *), shfwga_(integer *, integer *, integer *, integer *, 
+	    integer *, real *, real *, real *, real *), sholap_(integer *, 
+	    integer *, real *, real *), shfwgj_(integer *, integer *, integer 
+	    *, integer *, real *, real *, real *, real *), shfwgm_(integer *, 
+	    integer *, integer *, real *, real *, real *, real *, real *), 
+	    shinit_(integer *, integer *, integer *, real *, real *, real *, 
 	    real *, real *, real *, real *, real *, real *, real *, real *, 
-	    real *, real *), shmswa_(integer *, integer *, integer *, integer 
-	    *, integer *, real *, real *, real *, real *, real *, real *, 
-	    real *, real *), shpfun_(integer *, integer *, integer *, real *, 
-	    real *, real *, real *, real *, real *), shlbwu_(integer *, 
-	    integer *, integer *, integer *, real *, real *, real *, real *, 
-	    real *, real *, real *, real *), shlfwu_(integer *, integer *, 
+	    real *), shmswa_(integer *, integer *, integer *, integer *, 
+	    integer *, real *, real *, real *, real *, real *, real *, real *,
+	     real *), shpfun_(integer *, integer *, integer *, real *, real *,
+	     real *, real *, real *, real *), shlbwu_(integer *, integer *, 
 	    integer *, integer *, real *, real *, real *, real *, real *, 
-	    real *, real *, real *, real *, real *, real *), shmswj_(integer *
-	    , integer *, integer *, integer *, integer *, integer *, real *, 
-	    real *, real *, real *, real *, real *, real *, real *), shmswm_(
+	    real *, real *, real *), shlfwu_(integer *, integer *, integer *, 
+	    integer *, real *, real *, real *, real *, real *, real *, real *,
+	     real *, real *, real *, real *), shmswj_(integer *, integer *, 
 	    integer *, integer *, integer *, integer *, real *, real *, real *
-	    , real *, real *, real *, real *, real *, real *), shfwgz_(
-	    integer *, integer *, real *, real *), shmswz_(integer *, integer 
-	    *, integer *, real *, real *, real *, real *, real *, real *, 
-	    real *, real *);
-    static integer isd, ixc, nsd, iyc, ipm, nyc, nxc, npm, ipx, ipy, ixs, iys,
-	     npx, npy, ixw, nxs, nys, iyw, iwy, nxw, nyw, nwy, nwx, iwx;
+	    , real *, real *, real *, real *, real *), shmswm_(integer *, 
+	    integer *, integer *, integer *, real *, real *, real *, real *, 
+	    real *, real *, real *, real *, real *), shfwgz_(integer *, 
+	    integer *, real *, real *), shmswz_(integer *, integer *, integer 
+	    *, real *, real *, real *, real *, real *, real *, real *, real *)
+	    ;
 
 /*      REAL Q((JM+1)*(4*JM+5*MM+14)+(MM+1)*(MM+1)+MM+2+6*IM+15) */
 /*      REAL FUN(-JM:JM,M:MM) */
@@ -328,7 +333,7 @@ L_shtsga:
 L_shtsgz:
     shmswz_(mm, jm, isw, &s[1], &wz[1], &q[isd], &q[ipm], &q[iys], &q[iyc], &
 	    q[ipy], &q[ir]);
-    shfwgz_(jm, im, &w[1], &g[1]);
+    shfwgz_(jm, im, &wz[1], &g[1]);
     return 0;
 /* ---------------------------------------------------------------------- */
 /*     TRANSFORM SPECTRA INTO GRID (FOR M>0) */
