@@ -1,10 +1,16 @@
-/* Copyright (C) by GFD-Dennou Club, 1999-2000.  All rights reserved. */
-/* lchrl.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -14,6 +20,8 @@ static integer c__1 = 1;
 /* ----------------------------------------------------------------------- */
 /*     LCHRL */
 /* ----------------------------------------------------------------------- */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/* ----------------------------------------------------------------------- */
 logical lchrl_(char *ch, ftnlen ch_len)
 {
     /* Initialized data */
@@ -29,10 +37,9 @@ logical lchrl_(char *ch, ftnlen ch_len)
     integer i_len(char *, ftnlen);
 
     /* Local variables */
-    static integer nidx, i__;
+    static integer i__, nch, nidx;
     extern integer indxcf_(char *, integer *, integer *, char *, ftnlen, 
 	    ftnlen);
-    static integer nch;
 
     nch = i_len(ch, ch_len);
     ret_val = TRUE_;
