@@ -1,21 +1,28 @@
-/* datef1.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* ----------------------------------------------------------------------- */
 /*     DATEF1 */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int datef1_(integer *n, integer *idate, integer *ndate)
 {
+    static integer iy, ny, itd, ntd;
     extern /* Subroutine */ int date12_(integer *, integer *, integer *), 
 	    date21_(integer *, integer *, integer *), datef2_(integer *, 
 	    integer *, integer *, integer *, integer *);
-    static integer iy, ny, itd, ntd;
 
     date12_(idate, &iy, &itd);
     datef2_(n, &iy, &itd, &ny, &ntd);
